@@ -7,10 +7,10 @@
 **
 */
 
-#include "include/vine.h"
-#include "include/deriv.h"
-#include "include/tcopuladeriv.h"
-#include "include/tcopuladeriv_new.h"
+#include "vine.h"
+#include "deriv.h"
+#include "tcopuladeriv.h"
+#include "tcopuladeriv_new.h"
 
 #define UMAX  1-1e-10
 
